--[[
An ActionButton that has a defined behavior of "do nothing".  Normally, this
shows up as a typical cancel button (x), but can show up as a menu selection
with the word "Cancel" associated with it.  Other looks are also possible.

There is one ActionButtonNone per UnitGroupHeader.
Each ActionButtonNone instance is associated with a single UnitGroupHeader.
--]]
uab.classes.ActionButtonNone = uab.mixins.aceOO.Class()

function uab.classes.ActionButtonNone.ShowTooltip(frame)
    if uab.db.profile.tooltips then
        GameTooltip:SetOwner(frame, "ANCHOR_RIGHT")
        GameTooltip:SetBackdropColor(0.1, 0.1, 0.1, 0.8)
        GameTooltip:SetText("Cancel unit action", nil, nil, nil, nil, true)
    end
end

function uab.classes.ActionButtonNone.prototype:init(header)
	uab.classes.ActionButtonNone.super.prototype.init(self)
	
	self.header = header
	
	--[[
	Create frame
	--]]
    self.frame = CreateFrame(
        "Button",
        self.header.name.."ActionBtnNone",
        nil,
        "UAB_StandardCancelButtonTemplate")
    self.frame.uabobj = self
    self.frame:Show()

    self.frame:SetAttribute("useparent-unit", true)
    self.frame:SetAttribute("useparent-unitsuffix", true)
    self.frame:SetAttribute("state", "0")

    self:Enable()
	self:SetParent()
    
    self.frame:SetPoint("CENTER", 0, 0)
    self.frame:SetScript("OnEnter", function(self, motion) uab.classes.ActionButtonNone.ShowTooltip(self) end)
    self.frame:SetScript("OnShow", function(self)
        self.uabobj:OnShow()
    end)
    self.frame:SetScript("OnLeave", function(self, motion) GameTooltip:Hide() end)
    
    self.frame:Hide()
end

function uab.classes.ActionButtonNone.prototype:SetParent()
    if self.header.frame then
        self.frame:SetParent(self.header.frame)
	    self.header.frame:SetAttribute("addchild", self.frame)
    end
end

function uab.classes.ActionButtonNone.prototype:SetScale(scale)
    self.frame:SetScale(scale)
end

function uab.classes.ActionButtonNone.prototype:Show()
	-- Nothing to do here, since this is the cancel button, which does not
	-- change visual appearance.
end

function uab.classes.ActionButtonNone.prototype:Hide()
	self.frame:Hide()
end

function uab.classes.ActionButtonNone.prototype:Enable()
    self.frame:SetAttribute("showstates", self.header.states.min.."-"..self.header.states.max)
    self.frame:SetAttribute("hidestates", nil)
    self.frame:SetAttribute("newstate", "*:0")
	self.enabled = true
end

function uab.classes.ActionButtonNone.prototype:Disable()
    self.frame:SetAttribute("showstates", nil)
    self.frame:SetAttribute("hidestates", "*")
    self.frame:SetAttribute("newstate", "*:0")
	self.enabled = nil
end

function uab.classes.ActionButtonNone.prototype:Frame()
	return self.frame
end

function uab.classes.ActionButtonNone.prototype:OnShow()
    self.frame:SetFrameStrata("FULLSCREEN_DIALOG")
end

